@@ -1,4 +1,4 @@
-/*	$Id: Class1.h,v 1.5 2003/02/08 22:49:46 darren Exp $ */
+/*	$Id: Class1.h,v 1.22 2004/06/18 20:50:48 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -49,8 +49,16 @@ class Class1Modem : public FaxModem {
 protected:
     fxStr	thCmd;			// command for transmitting a frame
     fxStr	rhCmd;			// command for receiving a frame
+    fxStr	classCmd;		// set class command
+    u_int	serviceType;		// modem service required
     u_int	dis;			// current remote DIS
     u_int	xinfo;			// current remote DIS extensions
+    u_int	frameSize;		// size of image frames
+    u_int	signalRcvd;		// last signal received in ECM protocol
+    u_int	nonV34br;		// modemParams.br without V.34
+    bool	sentERR;		// whether or not ERR was sent
+    bool	hadV34Trouble;		// indicates failure due to V.34 restrictions
+    bool	batchingError;		// indicates failure due to batching protocol
     const u_char* frameRev;		// HDLC frame bit reversal table
     fxStr	lid;			// encoded local id string
     fxStr	pwd;			// transmit password
@@ -65,6 +73,17 @@ protected:
     bool	messageReceived;	// expect/don't expect message carrier
     u_int	lastPPM;		// last PPM during receive
     bool	sendCFR;		// received TCF was not confirmed
+    u_short	ecmBitPos;		// bit position to populate on ecmByte
+    u_int	ecmByte;		// pending byte to add to ecmBlock
+    u_short	ecmOnes;		// count of consecutive ones for adding zero bits
+    u_char*	ecmFrame;		// to hold outgoing frames as they are read from the file
+    u_int	ecmFramePos;		// fill pointer for ecmFrame
+    u_char*	ecmBlock;		// to hold 256 raw ecmFrames to send before MCF
+    u_long	ecmBlockPos;		// fill pointer for ecmBlock
+    u_char*	ecmStuffedBlock;	// to hold image block after adding transparent zeros and FCS bytes
+    u_long	ecmStuffedBlockPos;	// fill pointer for ecmStuffedBlockPos
+    u_short	frameNumber;		// frame sequence number of ecmFrame in ecmBlock
+    u_short	blockNumber;		// block sequence number of ecmBlock in page
 
     static const u_int modemPFMCodes[8];// map T.30 FCF to Class 2 PFM
     static const u_int modemPPMCodes[8];// map T.30 FCF to Class 2 PPM
@@ -82,6 +101,15 @@ protected:
     };
     static const char* modulationNames[6];
 
+// V.34 indicators
+    bool	useV34;		// whether or not V.8 handhaking was used
+    bool	gotEOT;		// V.34-fax heard EOT signal
+    bool	gotCTRL;	// current channel indicator
+    bool	gotRTNC;	// retrain control channel
+    u_short	primaryV34Rate;	// rate indication for primary channel
+    u_short	controlV34Rate;	// rate indication for control channel
+    fxStr	ctrlFrameRcvd;	// unexpected control channel frame received
+
 // modem setup stuff
     virtual bool setupModem();
     virtual bool setupClass1Parameters();
@@ -92,9 +120,9 @@ protected:
     bool	raiseToNextBR(Class2Params&);
     bool	sendTraining(Class2Params&, int, fxStr& emsg);
     bool	sendTCF(const Class2Params&, u_int ms);
-    bool	sendPage(TIFF* tif, const Class2Params&, u_int, fxStr& emsg);
-    bool	sendPageData(u_char* data, u_int cc, const u_char* bitrev);
-    bool	sendRTC(bool is2D);
+    bool	sendPage(TIFF* tif, Class2Params&, u_int, u_int, fxStr& emsg);
+    bool	sendPageData(u_char* data, u_int cc, const u_char* bitrev, bool ecm, fxStr& emsg);
+    bool	sendRTC(Class2Params params, u_int ppmcmd, int lastbyte, fxStr& emsg);
     bool	sendPPM(u_int ppm, HDLCFrame& mcf, fxStr& emsg);
     bool	decodePPM(const fxStr& pph, u_int& ppm, fxStr& emsg);
 // reception support
@@ -102,8 +130,9 @@ protected:
     bool	recvIdentification(
 		    u_int f1, const fxStr& pwd,
 		    u_int f2, const fxStr& addr,
-		    u_int f3, const fxStr& id,
-		    u_int f4, u_int dics, u_int xinfo,
+		    u_int f3, const fxStr& nsf,
+		    u_int f4, const fxStr& id,
+		    u_int f5, u_int dics, u_int xinfo,
 		    u_int timer, fxStr& emsg);
     bool	recvDCSFrames(HDLCFrame& frame);
     bool	recvTraining();
@@ -119,6 +148,7 @@ protected:
     virtual ATResponse atResponse(char* buf, long ms = 30*1000);
     virtual bool waitFor(ATResponse wanted, long ms = 30*1000);
     void	encodeTSI(fxStr& binary, const fxStr& ascii);
+    void	encodeNSF(fxStr& binary, const fxStr& ascii);
     const fxStr& decodeTSI(fxStr& ascii, const HDLCFrame& binary);
     void	encodePWD(fxStr& binary, const fxStr& ascii);
     const fxStr& decodePWD(fxStr& ascii, const HDLCFrame& binary);
@@ -128,44 +158,58 @@ protected:
     bool	transmitFrame(u_char fcf, bool lastFrame = true);
     bool	transmitFrame(u_char fcf, u_int, u_int, bool lastFrame = true);
     bool	transmitFrame(u_char fcf, const fxStr&, bool lastFrame=true);
+    bool	transmitFrame(u_char fcf, const u_char* code, const fxStr&, bool lastFrame=true);
     bool	transmitData(int br, u_char* data, u_int cc,
 		    const u_char* bitrev, bool eod);
     bool	sendFrame(u_char fcf, bool lastFrame = true);
     bool	sendFrame(u_char fcf, u_int, u_int, bool lastFrame = true);
     bool	sendFrame(u_char fcf, const fxStr&, bool lastFrame = true);
+    bool	sendFrame(u_char fcf, const u_char* code, const fxStr&, bool lastFrame = true);
     bool	sendRawFrame(HDLCFrame& frame);
     bool	sendClass1Data(const u_char* data, u_int cc,
 		    const u_char* bitrev, bool eod);
+    bool	sendClass1ECMData(const u_char* data, u_int cc,
+		     const u_char* bitrev, bool eod, u_int ppmcmd, fxStr& emsg);
     bool	recvFrame(HDLCFrame& frame, long ms = 10*1000);
     bool	recvTCF(int br, HDLCFrame&, const u_char* bitrev, long ms);
     bool	recvRawFrame(HDLCFrame& frame);
+    bool	recvECMFrame(HDLCFrame& frame);
+    bool        waitForDCEChannel(bool awaitctrl);
+    bool        renegotiatePrimary(bool constrain);
+    bool	syncECMFrame();
+    bool	recvPageECMData(TIFF* tif, const Class2Params& params, fxStr& emsg);
+    void	blockData(u_int byte, bool flag);
+    bool	blockFrame(const u_char* bitrev, bool lastframe, u_int ppmcmd, fxStr& emsg);
+    bool	endECMBlock();
     void	abortReceive();
     void	traceHDLCFrame(const char* direction, const HDLCFrame& frame);
 // class 1 command support routines
-    bool	class1Query(const char* what, Class1Cap caps[]);
+    bool	class1Query(const fxStr& queryCmd, Class1Cap caps[]);
     bool	parseQuery(const char*, Class1Cap caps[]);
 public:
     Class1Modem(FaxServer&, const ModemConfig&);
     virtual ~Class1Modem();
+    void	hangup();
 
 // send support
     bool	sendSetup(FaxRequest&, const Class2Params&, fxStr& emsg);
     CallStatus	dialResponse(fxStr& emsg);
-    FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&);
+    FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&, u_int&);
     void	sendBegin();
     void	sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     FaxSendStatus sendPhaseB(TIFF* tif, Class2Params&, FaxMachineInfo&,
-		    fxStr& pph, fxStr& emsg);
+		    fxStr& pph, fxStr& emsg, u_int& batched);
     void	sendEnd();
     void	sendAbort();
 
 // receive support
-    CallType	answerCall(AnswerType, fxStr& emsg);
+    CallType	answerCall(AnswerType, fxStr& emsg, const char* number);
     u_int	modemDIS() const;
     u_int	modemXINFO() const;
     bool	setupReceive();
     bool	recvBegin(fxStr& emsg);
-    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg);
+    bool	recvEOMBegin(fxStr& emsg);
+    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg, const fxStr& id);
     bool	recvEnd(fxStr& emsg);
     void	recvAbort();
 
@@ -175,8 +219,9 @@ public:
 		    fxStr& emsg);
 
 // miscellaneous
-    bool	faxService();			// switch to fax mode
+    bool	faxService(bool enableV34);	// switch to fax mode
     bool	reset(long ms);			// reset modem
+    bool	ready(long ms);			// ready modem
     void	setLID(const fxStr& number);	// set local id string
     bool	supportsPolling() const;	// modem capability
 };
