@@ -1,4 +1,4 @@
-/*	$Id: Class2.h,v 1.7 2003/02/08 22:49:47 darren Exp $ */
+/*	$Id: Class2.h,v 1.16 2004/06/18 20:50:48 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -61,6 +61,7 @@ protected:
     fxStr	hardFlowCmd;		// hardware flow control command
     u_int	serviceType;		// modem service required
     u_int	modemCQ;		// copy quality capabilities mask
+    u_int	sendCQ;			// sending copy quality capabilities mask
 
     bool	xmitWaitForXON;		// if true, wait for XON when sending
     bool	hostDidCQ;		// if true, copy quality done on host
@@ -79,7 +80,7 @@ protected:
     virtual bool setupFlowControl(FlowControl fc);
 // transmission support
     bool	dataTransfer();
-    bool	sendRTC(bool is2D);
+    bool	sendRTC(Class2Params params);
     bool	sendPageData(TIFF* tif, u_int pageChop);
 
     virtual bool sendPage(TIFF* tif, u_int pageChop) = 0;
@@ -137,15 +138,16 @@ public:
 // send support
     bool	sendSetup(FaxRequest&, const Class2Params&, fxStr& emsg);
     CallStatus	dialResponse(fxStr& emsg);
-    FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&);
+    FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&, u_int&);
     FaxSendStatus sendPhaseB(TIFF* tif, Class2Params&, FaxMachineInfo&,
-		    fxStr& pph, fxStr& emsg);
+		    fxStr& pph, fxStr& emsg, u_int& batched);
     void	sendAbort();
 
 // receive support
     bool	setupReceive();
     bool	recvBegin(fxStr& emsg);
-    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg);
+    bool	recvEOMBegin(fxStr& emsg);
+    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg, const fxStr& id);
     bool	recvEnd(fxStr& emsg);
     void	recvAbort();
 
@@ -155,9 +157,10 @@ public:
 		    fxStr& emsg);
 
 // miscellaneous
-    bool	faxService();			// switch to fax mode
+    bool	faxService(bool enableV34);	// switch to fax mode
     bool	reset(long ms);			// reset modem
     void	setLID(const fxStr& number);	// set local id string
     bool	supportsPolling() const;	// modem capability
+    int		lastByte;
 };
 #endif /* _CLASS2_ */
