@@ -1,4 +1,4 @@
-/*	$Id: FaxModem.h,v 1.14 2003/04/26 07:11:21 robert Exp $ */
+/*	$Id: FaxModem.h,v 1.27 2004/06/18 20:50:49 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -75,6 +75,9 @@ private:
     tstrip_t	recvStrip;	// current strip number during receive
     u_char*	recvRow;	// current receive row raster
     u_long	savedWriteOff;	// file offset to start of page data
+    int		decoderFd[2];	// file descriptors for the decoder pipe
+    int		counterFd[2];	// file descriptors for the counter pipe
+    pid_t	decoderPid;	// process id for the decoding process
 
     void	flushEncodedData(TIFF*, tstrip_t, const u_char*, u_int);
     void	flushRawData(TIFF*, tstrip_t, const u_char*, u_int);
@@ -105,6 +108,7 @@ protected:
 
 // miscellaneous
     void	countPage();
+    int		getPageNumber();
     void	recvTrace(const char* fmt, ...);
     void	copyQualityTrace(const char* fmt, ...);
     void	traceModemParams();
@@ -120,7 +124,7 @@ protected:
     void	recvNSF(const NSF&);
     void	recvCSI(const fxStr&);
     void	recvDCS(const Class2Params&);
-    void	recvSetupTIFF(TIFF* tif, long group3opts, int fillOrder);
+    void	recvSetupTIFF(TIFF* tif, long group3opts, int fillOrder, const fxStr& id);
     void	recvStartPage(TIFF* tif);
     void	recvResetPage(TIFF* tif);
     u_int	decodePageChop(const fxStr& pph, const Class2Params&);
@@ -129,6 +133,10 @@ protected:
 // phase c data receive & copy quality checking
     bool	recvPageDLEData(TIFF* tif, bool checkQuality,
 		    const Class2Params& params, fxStr& emsg);
+    void	setupStartPage(TIFF* tif, const Class2Params& params);
+    void	recvEndPage(TIFF* tif, const Class2Params& params);
+    void	writeECMData(TIFF*, u_char*, u_int, const Class2Params&, u_short);
+    void	initializeDecoder(const Class2Params&);
     virtual void abortPageRecv() = 0;
     virtual int nextByte();
 
@@ -140,12 +148,17 @@ protected:
 // tag line support
     bool	setupTagLineSlop(const Class2Params&);
     u_int	getTagLineSlop() const;
-    u_char*	imageTagLine(u_char* buf, u_int fillorder, const Class2Params&);
+    u_char*	imageTagLine(u_char* buf, u_int fillorder, const Class2Params&, u_long& totdata);
 /*
- * Correct if neccessary Phase C (T.4) data (remove extra RTC etc.)
+ * Correct if neccessary Phase C (T.4/T.6) data (remove extra RTC/EOFB etc.)
  */
-    void        correctPhaseCData(u_char* buf, u_long* pBufSize,
+    int		correctPhaseCData(u_char* buf, u_long* pBufSize,
                                   u_int fillorder, const Class2Params& params);
+/*
+ * Convert Phase C data...
+ */
+    u_char*	convertPhaseCData(u_char* buf, u_long& totdata, u_int fillorder,
+                            const Class2Params& params, const Class2Params& newparams);
 public:
     enum {			// FaxModem::RTNHandling
         RTN_RETRANSMIT = 0,         // retransmit page after RTN until MCF/MPS
@@ -165,10 +178,10 @@ public:
     virtual bool supportsMMR() const;
     virtual bool supportsEOLPadding() const;
     virtual bool supportsVRes(float res) const;
-    virtual bool supportsPageWidth(u_int w) const;
+    virtual bool supportsPageWidth(u_int w, u_int r) const;
     virtual bool supportsPageLength(u_int l) const;
     virtual bool supportsPolling() const;
-    virtual bool supportsECM() const;
+    virtual bool supportsECM(u_int ec = 0) const;
 
     virtual int selectSignallingRate(int br) const;
     u_int getBestSignallingRate() const;
@@ -176,7 +189,7 @@ public:
     u_int getBestScanlineTime() const;
     virtual int selectScanlineTime(int st) const;
 
-    u_int getBestVRes() const;
+    u_int getVRes() const;
     u_int getBestDataFormat() const;
     u_int getBestPageWidth() const;
     u_int getBestPageLength() const;
@@ -205,14 +218,14 @@ public:
      * for doing things like keeping cover pages & documents in a
      * single T.30 document.
      */
-    virtual bool faxService() = 0;
+    virtual bool faxService(bool enableV34) = 0;
     virtual bool sendSetup(FaxRequest&, const Class2Params& dis, fxStr& emsg);
     virtual void sendBegin();
     virtual FaxSendStatus getPrologue(Class2Params&,
-	bool& hasDoc, fxStr& emsg) = 0;
+	bool& hasDoc, fxStr& emsg, u_int& batched) = 0;
     virtual void sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     virtual FaxSendStatus sendPhaseB(TIFF*, Class2Params&, FaxMachineInfo&,
-	fxStr& pph, fxStr& emsg) = 0;
+	fxStr& pph, fxStr& emsg, u_int& batched) = 0;
     virtual void sendEnd();
     virtual void sendAbort() = 0;
     // query interfaces for optional state
@@ -249,9 +262,11 @@ public:
      */
     virtual bool setupReceive() = 0;
     virtual bool recvBegin(fxStr& emsg);
-    virtual bool recvPage(TIFF*, u_int& ppm, fxStr& em) = 0;
+    virtual bool recvEOMBegin(fxStr& emsg);
+    virtual bool recvPage(TIFF*, u_int& ppm, fxStr& em, const fxStr& id) = 0;
     virtual bool recvEnd(fxStr& emsg) = 0;
     virtual void recvAbort() = 0;
+    virtual void recvSucceeded();
     // query interfaces for optional state
     virtual bool getRecvPWD(fxStr&);
     virtual bool getRecvTSI(fxStr&);
