@@ -1,4 +1,4 @@
-/*	$Id: FaxServer.h,v 1.5 2003/02/09 02:22:49 darren Exp $ */
+/*	$Id: FaxServer.h,v 1.12 2004/06/28 19:23:56 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -61,9 +61,9 @@ private:
     friend class FaxModem;
 
 // FAX transmission protocol support
-    void	sendFax(FaxRequest& fax, FaxMachineInfo&, const fxStr& number);
+    void	sendFax(FaxRequest& fax, FaxMachineInfo&, const fxStr& number, u_int&);
     bool	sendClientCapabilitiesOK(FaxRequest&, FaxMachineInfo&, fxStr&);
-    bool	sendFaxPhaseB(FaxRequest&, faxRequest&, FaxMachineInfo&);
+    bool	sendFaxPhaseB(FaxRequest&, FaxItem&, FaxMachineInfo&, u_int, bool);
     void	sendPoll(FaxRequest& fax, bool remoteHasDoc);
     FaxSendStatus sendSetupParams(TIFF*,
 		    Class2Params&, const FaxMachineInfo&, fxStr&);
@@ -90,7 +90,7 @@ protected:
     void	readConfig(const fxStr& filename);
     void	setLocalIdentifier(const fxStr& lid);
 
-    void	sendFax(FaxRequest&, FaxMachineInfo&, FaxAcctInfo&);
+    void	sendFax(FaxRequest&, FaxMachineInfo&, FaxAcctInfo&, u_int&);
     bool	recvFax(const CallerID& cid);
 
     time_t	getFileTransferTime() const;
@@ -108,7 +108,7 @@ protected:
     virtual void notifyRecvBegun(const FaxRecvInfo&);
     virtual void notifyPageRecvd(TIFF* tif, const FaxRecvInfo&, int ppm);
     virtual void notifyDocumentRecvd(const FaxRecvInfo& req);
-    virtual void notifyRecvDone(const FaxRecvInfo& req, const CallerID& cid);
+    virtual void notifyRecvDone(const FaxRecvInfo& req);
 public:
     virtual ~FaxServer();
 
@@ -120,7 +120,6 @@ public:
     bool modemSupportsMMR() const;
     bool modemSupportsEOLPadding() const;
     bool modemSupportsVRes(float res) const;
-    bool modemSupportsPageWidth(u_int w) const;
     bool modemSupportsPageLength(u_int l) const;
     bool modemSupportsPolling() const;
 };
