@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h,v 1.18 2003/02/09 02:03:13 darren Exp $ */
+/*	$Id: ModemConfig.h,v 1.33 2004/06/01 21:34:40 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -40,6 +40,7 @@ private:
     u_int	getSpeed(const char* value);
     u_int	getDataFormat(const char* value);
     u_int       getRTNHandling(const char* cp);
+    ECMType	getECMType(const char* cp);
 
     static bool findRate(const char*, BaudRate&);
     static bool findATResponse(const char*, ATResponse&);
@@ -58,12 +59,14 @@ protected:
     fxStr parseATCmd(const char*);
 public:
     fxStr	type;			// modem type
-    fxStr	resetCmds;		// extra modem reset commands
+    fxStr	resetCmds;		// extra modem reset commands for start of initialization
+    fxStr	readyCmds;		// extra modem reset commands for end of initialization
     fxStr	dialCmd;		// cmd for dialing (%s for number)
     fxStr	answerAnyCmd;		// cmd for answering unknown call type
     fxStr	answerDataCmd;		// cmd for answering data call
     fxStr	answerFaxCmd;		// cmd for answering fax call
     fxStr	answerVoiceCmd;		// cmd for answering voice call
+    fxStr	answerDialCmd;		// cmd for answering a dialed call
     fxStr	ringResponse;		// cmd to respond after AT_RING
     fxStr	hardFlowCmd;		// cmd for hardware flow control
     fxStr	softFlowCmd;		// cmd for software flow control
@@ -79,6 +82,7 @@ public:
     fxStr	onHookCmd;		// cmd for placing phone ``on hook''
     fxStr	softResetCmd;		// cmd for doing soft reset
     u_int	softResetCmdDelay;	// time in ms to pause after soft reset
+    u_int	ringsBeforeResponse;	// number of rings to wait before ModemRingResponse
     u_int	ringTimeout;		// timeout in ms after RING to reset
     fxStr	waitTimeCmd;		// cmd for setting carrier wait time
     fxStr	pauseTimeCmd;		// cmd for setting "," pause time
@@ -90,6 +94,7 @@ public:
     fxStr	answerFaxBeginCmd;	// cmd to start inbound fax session
     fxStr	answerVoiceBeginCmd;	// cmd to start inbound voice session
     fxStr	sendBeginCmd;		// cmd to start outbound session
+    fxStr	recvSuccessCmd;		// cmd for after successful reception
     fxStr	class0Cmd;		// cmd for setting Class 0
     fxStr	classQueryCmd;		// cmd for getting modem services
 					// distinctive ring
@@ -113,12 +118,15 @@ public:
     u_int	pageDoneTimeout;	// page send/receive timeout (ms)
 					// for class 1:
     fxStr	class1Cmd;		// cmd for setting Class 1
+    fxStr	class1EnableV34Cmd;	// cmd to enable V.34 support in Class 1.0
     fxStr	class1NFLOCmd;		// cmd to setup no flow control
     fxStr	class1SFLOCmd;		// cmd to setup software flow control
     fxStr	class1HFLOCmd;		// cmd to setup hardware flow control
     fxStr	class1PPMWaitCmd;	// cmd to stop and wait prior to PPM
     fxStr	class1ResponseWaitCmd;	// cmd to wait prior to TCF response
+    fxStr	class1RMQueryCmd;	// cmd to query modem for receive demodulators
     fxStr	class1TCFWaitCmd;	// cmd to stop and wait prior to TCF
+    fxStr	class1TMQueryCmd;	// cmd to query modem for transmit modulators
     fxStr	class1EOPWaitCmd;	// cmd to stop and wait prior to EOP
     fxStr	class1SwitchingCmd;	// after recv HDLC and before sending
     fxStr	class1MsgRecvHackCmd;	// cmd to avoid +FCERROR before image
@@ -131,7 +139,13 @@ public:
     u_int	class1RecvIdentTimer;	// timeout receiving initial identity
     u_int	class1TCFMaxNonZero;	// non-zero threshold for TCF check
     u_int	class1TCFMinRun;	// min length of zero run for TCF check
+    u_int	class1TMConnectDelay;	// delay (ms) after +FTM CONNECT
+    u_int	class1ECMFrameSize;	// ECM frame size for transmission
+    bool	class1ECMSupport;	// support T.30-A ECM
+    bool	class1PersistentECM;	// continue to correct
+    bool	class1ExtendedRes;	// support for extended resolutions
     bool	class1TCFRecvHack;	// deliberately look for V.21 disconnect
+    bool	class1ValidateV21Frames;// check received FCS values in V.21
 					// for class 2 and 2.0:
     fxStr	class2Cmd;		// cmd for setting Class 2/2.0
     fxStr	class2DCCQueryCmd;	// cmd to query modem capabilities
@@ -166,10 +180,13 @@ public:
 					// for class T.class2:
     fxStr	class2APQueryCmd;	// cmd to query address&polling caps.
     fxStr	class2APCmd;		// cmd to setup address&polling caps.
+    ECMType	class2ECMType;		// ECM specification type to use
     fxStr	class2SACmd;		// cmd to set subaddress
     fxStr	class2PACmd;		// cmd to set selective polling address
     fxStr	class2PWCmd;		// cmd to set password for transmit/poll
     bool	class2UseHex;		// parse capabilities strings as hex
+    bool	class2HexNSF;		// parse nsf strings as hex
+    bool	class2UseLineCount;	// use the firmware decoder's line count
 
     FlowControl	flowControl;		// DTE-DCE flow control method
     BaudRate	maxRate;		// max DTE-DCE rate to try
@@ -183,12 +200,14 @@ public:
     u_int	percentGoodLines;	// required % of good lines in page
     u_int	maxConsecutiveBadLines;	// max consecutive bad lines in page
     u_int	minSpeed;		// minimum speed for fax transmits
+    bool	softRTFCC;		// real-time fax compression conversion (software)
     bool	waitForConnect;		// modem sends multiple answer responses
     fxStr	tagLineFmt;		// format string for tag lines
     fxStr	tagLineFontFile;	// font file for imaging tag lines
     u_int	recvDataFormat;		// received facsimile data format
 
     RTNHandling rtnHandling;            // RTN signal handling method
+    bool	saveUnconfirmedPages;	// don't delete unconfirmed pages
     
         virtual ~ModemConfig();
 
