@@ -1,4 +1,4 @@
-/*	$Id: faxGettyApp.h,v 1.5 2002/10/18 19:08:29 darren Exp $ */
+/*	$Id: faxGettyApp.h,v 1.10 2004/06/22 16:03:36 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -69,7 +69,7 @@ private:
     u_short	ringsHeard;		// # rings received
     fxStr	qualifyCID;		// if set, no answer w/o acceptable cid
     time_t	lastCIDModTime;		// last mod time of CID patterns file
-    RegExArray*	cidPats;		// recv cid patterns
+    REArray*	cidPats;		// recv cid patterns
     fxBoolArray* acceptCID;		// accept/reject matched cid
     CallerID	received_cid;		// non-null received CNID
     fxStr	gettyArgs;		// getty arguments
@@ -84,6 +84,7 @@ private:
     u_short	answerRotorSize;	// rotor table size
     AnswerType	answerRotary[3];	// rotary selection of answer types
     fxStr	faxRcvdCmd;		// fax received command
+    fxStr	dynamicConfig;		// command to dynamically alter configuration
     u_int	modemPriority;		// modem priority passed to faxq
 
     static faxGettyApp* _instance;
@@ -116,10 +117,10 @@ private:
     void	setRingsBeforeAnswer(int rings);
     void	listenBegin();
     void	listenForRing();
-    void	answerPhoneCmd(AnswerType);
-    void	answerPhone(AnswerType, CallType, const CallerID& cid);
+    void	answerPhoneCmd(AnswerType, const char* dialnumber = NULL);
+    void	answerPhone(AnswerType, CallType, const CallerID& cid, const char* dialnumber = NULL);
     void	answerCleanup();
-    bool	answerCall(AnswerType atype, CallType& ctype, fxStr& emsg, const CallerID& cid);
+    bool	answerCall(AnswerType atype, CallType& ctype, fxStr& emsg, const CallerID& cid, const char* dialnumber = NULL);
 
     friend void AnswerTimeoutHandler::timerExpired(long, long);
 // miscellaneous stuff
@@ -136,7 +137,7 @@ private:
     void	notifyRecvBegun(const FaxRecvInfo&);
     void	notifyPageRecvd(TIFF* tif, const FaxRecvInfo&, int ppm);
     void	notifyDocumentRecvd(const FaxRecvInfo&);
-    void	notifyRecvDone(const FaxRecvInfo&, const CallerID&);
+    void	notifyRecvDone(const FaxRecvInfo&);
 public:
     faxGettyApp(const fxStr& device, const fxStr& devID);
     ~faxGettyApp();
