@@ -1,4 +1,4 @@
-/*	$Id: faxQueueApp.h,v 1.7 2003/05/16 02:15:46 darren Exp $ */
+/*	$Id: faxQueueApp.h,v 1.10 2004/04/19 18:44:53 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -41,7 +41,7 @@ typedef	struct tiff TIFF;
 class Class2Params;
 class DialStringRules;
 class UUCPLock;
-class faxRequest;
+class FaxItem;
 class Modem;
 class Trigger;
 
@@ -80,7 +80,7 @@ private:
     fxStr	configFile;		// configuration filename
     fxStr	contCoverPageTemplate;	// continuation cover page template
     u_int	postscriptTimeout;	// timeout on PostScript imager calls
-    u_int	maxConcurrentJobs;	// max parallel jobs to a destination
+    u_int	maxConcurrentCalls;	// max parallel jobs to a destination
     u_int	maxSendPages;		// max pages in a send job
     u_int	maxDials;		// max times to dial the phone for a job
     u_int	maxTries;		// max transmits tried for a job
@@ -171,6 +171,7 @@ private:
     void	stopTimeout(const char* whichdir);
     const fxStr& pickCmd(const FaxRequest& req);
 // FIFO-related stuff
+    void	childStatus(pid_t, int);	// Dispatcher hook
     int		inputReady(int);		// Dispatcher hook
     void	openFIFOs();
     void	closeFIFOs();
@@ -226,7 +227,7 @@ private:
     JobStatus	prepareJob(Job& job, FaxRequest& req,
 		    const FaxMachineInfo&, const DestControlInfo&);
     JobStatus	convertDocument(Job&,
-		    const faxRequest& input, const fxStr& outFile,
+		    const FaxItem& input, const fxStr& outFile,
 		    const Class2Params& params,
 		    const DestControlInfo& dci, fxStr& emsg);
     JobStatus	runConverter(Job& job, const char* app, char* const* argv,
@@ -255,7 +256,7 @@ public:
 
     // used by DestControlInfo for default values
     u_int	getTracingLevel() const;
-    u_int	getMaxConcurrentJobs() const;
+    u_int	getMaxConcurrentCalls() const;
     u_int	getMaxSendPages() const;
     u_int	getMaxDials() const;
     u_int	getMaxTries() const;
