@@ -1,4 +1,4 @@
-/*	$Id: pageSendApp.h,v 1.4 2002/10/18 19:08:30 darren Exp $ */
+/*	$Id: pageSendApp.h,v 1.5 2003/11/20 15:20:38 aidan Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -86,7 +86,7 @@ private:
 		    const fxStr&);
 // IXO transmission support
     void	sendIxoPage(FaxRequest&, FaxMachineInfo&, const fxStr&, fxStr&);
-    bool	sendPagerMsg(FaxRequest&, faxRequest&, const fxStr&, fxStr&);
+    bool	sendPagerMsg(FaxRequest&, FaxItem&, const fxStr&, fxStr&);
     u_int	getResponse(fxStackBuffer& buf, long secs);
     bool	prepareMsg(FaxRequest&, FaxMachineInfo&, fxStr&);
     bool	pagePrologue(FaxRequest&, const FaxMachineInfo&, fxStr&);
@@ -96,7 +96,7 @@ private:
     void	notifyPageSent(FaxRequest& req, u_int fi);
     time_t	getConnectTime() const;
 // UCP transmission support
-    void	sendUcpPage(FaxRequest&, FaxMachineInfo&, const fxStr&, fxStr&);    bool	sendUcpMsg(FaxRequest&, faxRequest&, const fxStr&, fxStr&,
+    void	sendUcpPage(FaxRequest&, FaxMachineInfo&, const fxStr&, fxStr&);    bool	sendUcpMsg(FaxRequest&, FaxItem&, const fxStr&, fxStr&,
 		    FaxMachineInfo&);
 // modem handling
     bool	canLockModem();
