@@ -1,4 +1,4 @@
-/*	$Id: HylaFAXServer.h,v 1.5 2002/06/15 18:00:09 darren Exp $ */
+/*	$Id: HylaFAXServer.h,v 1.10 2004/04/27 20:16:15 lhoward Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -36,7 +36,17 @@
 #include "FileCache.h"
 #include "Trace.h"
 #include "Trigger.h"
-#include "Syslog.h"
+#include "SystemLog.h"
+
+#include "config.h"
+
+#ifdef HAVE_PAM
+extern "C" {
+#include <security/pam_appl.h>
+#include <security/pam_misc.h>
+#include <grp.h>
+}
+#endif // HAVE_PAM
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -117,7 +127,7 @@ enum Token {
     T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_STATE,	T_STATUS,
     T_SUBADDR,	 T_TAGLINE,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,
     T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_USE_CONTCOVER,
-    T_USE_ECM,	 T_USE_TAGLINE,	T_USRKEY,	T_VRES,
+    T_USE_ECM,	 T_USE_TAGLINE,	T_USE_XVRES,	T_USRKEY,	T_VRES,
     /*
      * SNPP tokens.
      */
@@ -150,7 +160,7 @@ extern const char* fmtTime(time_t t);
 /*
  * An instance of a fax server process.
  */
-class HylaFAXServer : public Syslog, public FaxConfig, public IOHandler {
+class HylaFAXServer : public SystemLog, public FaxConfig, public IOHandler {
 public:
     struct stringtag {
         const char*	 name;
@@ -213,6 +223,8 @@ protected:
     u_int	adminAttempts;		// number of failed admin attempts
     u_int	maxAdminAttempts;	// admin failures before server exits
     fxStr	the_user;		// name of user
+	fxStr   admingroup;			// name of local user group that is allowed
+								// to administer the fax server
     IDCache*	idcache;		// fax UID -> name mapping table
     /*
      * File and file-transfer related state.
@@ -330,8 +342,11 @@ protected:
     void setFileOwner(const char* filename);
 
     void loginRefused(const char* why);
+	bool pamCheck(const char* user=NULL, const char* pass=NULL);
+	bool pamIsAdmin(const char* user=NULL);
     bool checkUser(const char*);
     bool checkuser(FILE*, const char *name);
+    bool checkuser(const char *name);
     void login(void);
     void end_login(void);
     virtual void dologout(int status);
@@ -428,7 +443,7 @@ protected:
     bool jgrp_param(fxStr& jgid);
     bool pathname(fxStr& s);
     bool CRLF();
-    bool SP();
+    bool SPACE();
     bool COMMA();
     bool TIMESPEC(u_int len, time_t& result);
     bool BOOLEAN(bool& b);
@@ -538,9 +553,8 @@ protected:
     const char* compactTime(time_t t);
     void Jprintf(FILE* fd, const char* fmt, const Job& job);
 
-    u_int getSequenceNumber(const char* file, u_int howmany, fxStr&);
     u_int getJobNumber(fxStr&);
-    u_int getDocumentNumbers(u_int count, fxStr&);
+    u_int getDocumentNumber(fxStr&);
 
     bool getRecvDocStatus(RecvInfo& ri);
     RecvInfo* getRecvInfo(const fxStr& qfile, const struct stat& sb);
